@@ -1,5 +1,5 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-09 09:19:47 mtw>
+# Last changed Time-stamp: <2015-02-09 15:09:19 fall>
 
 
 package Bio::ViennaNGS::Util;
@@ -529,6 +529,52 @@ The conversion from BED to bigBed is done by a third-party utility
 (bedToBigBed), which is executed by L<IPC::Cmd>.
 
 
+=item unique_array
+
+Takes a reference to an array and uniques entries via hash copy.
+Returns a reference to an array containing unique values.
+
+=item kmer_enrichment
+
+Takes a reference to a sequence array and the length of the desired
+kmer.  Counts occurences of kmers of given length and returns a
+reference to a hash containing the kmer as key and occurences as
+value.
+
+=item extend_chain
+
+Takes a hash containing chromosomes and their corresponding sizes, as
+e.g. returned by the L<fetch_chrom_sizes> method. Second argument is a
+chain as generated by L<parse_bed6>.
+
+This chain is then either extended to the desired minimal size, extend
+from either the 5' and/or 3' end of the chain or returns only the 5'
+or 3' extended region plus an optional extension into the existing
+chain.
+
+=item parse_bed6
+
+Takes a path to a bed6 file optionally containing additional fields and returns a reference to an array of L<ViennaNGS::Feature> objects. This array can then easily be used for creation of an L<ViennaNGS::FeatureChain> object.
+
+=item fetch_chrom_sizes
+
+Takes the name of the desired species (e.g. hg19, mm9, ..) and
+retrieves annotated chromosomes and their sizes from UCSC. This
+methods returns a reference to a hash containing chromosomes as kays
+and their corresponding size as value. Either uses the fetchChromSizes
+util of the UCSC bin collection or alternatively and if mysql is
+available via a mysql command.
+
+=item mkdircheck
+
+Takes the path to one or more directories, converts them to an OS
+specific path and creates directories.
+
+=item rmdircheck
+
+Takes the path to one or more directories, converts them to an OS
+specific path and removes directories.
+
 =back
 
 =head1 DEPENDENCIES
@@ -562,6 +608,8 @@ available on your system, and that hey can be found and executed by
 the Perl interpreter. We recommend installing the latest version of
 L<BEDtools|https://github.com/arq5x/bedtools2> on your system.
 
+Examples for using most of the provided methods can be found at L<ViennaNGS::Tutorial>.
+
 =head1 AUTHORS
 
 =over
